@@ -1,4 +1,4 @@
-/* -*- Mode: C; c-basic-offset: 8 -*-
+/* -*- Mode: C; c-basic-offset: 4 -*-
  * libglade - a library for building interfaces from XML files at runtime
  * Copyright (C) 1998-2001  James Henstridge <james@daa.com.au>
  *
@@ -22,33 +22,40 @@
 #ifndef GLADE_BUILD_H
 #define GLADE_BUILD_H
 
+#include <glib.h>
+#include <glib-object.h>
+#include <gmodule.h>
 #include <glade/glade-xml.h>
-#include <gtk/gtktypeutils.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkaccelgroup.h>
 #include <gtk/gtkadjustment.h>
 
-#include <glade/glade-widget-tree.h>
+#include <glade/glade-parser.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 	
 /* create a new widget of some type.  Don't parse `standard' widget options */
 typedef GtkWidget *(* GladeNewFunc) (GladeXML *xml,
+				     GType widget_type,
 				     GladeWidgetInfo *info);
 /* call glade_xml_build_widget on each child node, and pack in self */
 typedef void (* GladeBuildChildrenFunc) (GladeXML *xml,
-					 GtkWidget *w,
+					 GtkWidget *parent,
 					 GladeWidgetInfo *info,
 					 const char *longname);
+typedef GtkWidget *(* GladeFindInternalChildFunc) (GladeXML *xml,
+						   GtkWidget *parent,
+						   const char *childname);
 
 typedef struct _GladeWidgetBuildData GladeWidgetBuildData;
 struct _GladeWidgetBuildData {
-  char *name;
-  GladeNewFunc new;
-  GladeBuildChildrenFunc build_children;
+    char *name;
+    GladeNewFunc new;
+    GladeBuildChildrenFunc build_children;
+    GType (* get_type_func)(void);
+    GType typecode;  /* this member takes precedence over get_type_func */
+    GladeFindInternalChildFunc find_internal_child;
 };
 
 /* widgets is a static, NULL terminated array of GladeWidgetBuildData's.
@@ -66,15 +73,16 @@ GtkAccelGroup *glade_xml_pop_accel(GladeXML *xml);
 /* make sure that xml->priv->accel_group is a valid AccelGroup */
 GtkAccelGroup *glade_xml_ensure_accel(GladeXML *xml);
 
-/* functions for manipulating the uline accel group stack */
-void           glade_xml_push_uline_accel(GladeXML *xml, GtkAccelGroup *uline);
-void           glade_xml_pop_uline_accel (GladeXML *xml);
-GtkAccelGroup *glade_xml_get_uline_accel (GladeXML *xml);
-
+#if 0
 /* this is the handler for GtkLabel accelerators */
 void           glade_xml_handle_label_accel(GladeXML *xml, const gchar *target,
 					    guint key);
 guint          glade_xml_get_parent_accel  (GladeXML *xml);
+#endif
+
+gboolean glade_xml_set_value_from_prop (GType widget_type,
+					GValue *value,
+					GladeProperty *prop);
 
 /* set standard properties on a GtkWindow widget */
 void           glade_xml_set_window_props (GtkWindow *window,
@@ -84,6 +92,14 @@ void           glade_xml_set_window_props (GtkWindow *window,
 GtkWidget *glade_xml_build_widget(GladeXML *self, GladeWidgetInfo *info,
 				  const char *parent_long);
 
+/* this function is used to get a pointer to the internal child of a
+ * container widget.  It would generally be called by the
+ * build_children callback for any children with the internal_child
+ * name set. */
+void glade_xml_handle_internal_child(GladeXML *self, GtkWidget *parent,
+				     GladeChildInfo *child_info,
+				     const gchar *parent_long);
+
 /* This function performs half of what glade_xml_build_widget does.  It is
  * useful when the widget has already been created.  Usually it would not
  * have any use at all. */
@@ -92,6 +108,13 @@ void       glade_xml_set_common_params(GladeXML *self,
 				       GladeWidgetInfo *info,
 				       const char *parent_long);
 
+gboolean glade_xml_set_value_from_string (GParamSpec *pspec,
+					  const gchar *string,
+					  GValue *value);
+
+GtkWidget *glade_standard_build_widget(GladeXML *xml, GType widget_type,
+				       GladeWidgetInfo *info);
+
 /* A standard child building routine that can be used in widget builders */
 void glade_standard_build_children(GladeXML *self, GtkWidget *w,
 				   GladeWidgetInfo *info,const char *longname);
@@ -101,7 +124,8 @@ GtkAdjustment *glade_get_adjustment(GladeWidgetInfo *info);
 
 /* this is a wrapper for gtk_type_enum_find_value, that just returns the
  * integer value for the enum */
-gint glade_enum_from_string(GtkType type, const char *string);
+gint  glade_enum_from_string(GType type, const char *string);
+guint glade_flags_from_string(GType type, const char *string);
 
 /* a wrapper for gettext */
 char *glade_xml_gettext(GladeXML *xml, const char *msgid);
@@ -112,8 +136,24 @@ GtkWidget *glade_create_custom(GladeXML *xml, gchar *func_name, gchar *name,
 			       gint int1, gint int2);
 
 
-#ifdef __cplusplus
+/* the module dynamic loading interface ... */
+
+/* increase this when there is a binary incompatible change in the
+ * libglade module API */
+#define GLADE_MODULE_API_VERSION 1
+gchar *glade_module_check_version(gint version);
+
+#define GLADE_MODULE_CHECK_INIT \
+G_MODULE_EXPORT const gchar *g_module_check_init(GModule *gmodule); \
+const gchar * \
+g_module_check_init(GModule *gmodule) \
+{ \
+  return dia_plugin_check_version(DIA_PLUGIN_API_VERSION); \
 }
-#endif /* __cplusplus */
+
+/* prototype for plugin init function (should be implemented by plugin) */
+G_MODULE_EXPORT void glade_module_register_widgets(void);
+
+G_END_DECLS
 	
 #endif
